Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CombineErrors ¶
CombineErrors reports the first non-nil error in the list.
Types ¶
type File ¶
type File struct {
// contains filtered or unexported fields
}
File wraps an output, and handles various details with tool output, such as possibly directing output to standard out, and deleting an incomplete output file if there was an error.
Click to show internal directories.
Click to hide internal directories.